Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(969)

Unified Diff: pkg/analyzer/lib/src/generated/engine.dart

Issue 876703003: Issue 22155. Send outline for both parsed and resolved Dart units. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analysis_server/lib/src/operation/operation_analysis.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/generated/engine.dart
diff --git a/pkg/analyzer/lib/src/generated/engine.dart b/pkg/analyzer/lib/src/generated/engine.dart
index a3529a792f3d0cca271c571e8e4d22b58289dce8..cac9971da07ef7905fce927bdfecc4f996f413f4 100644
--- a/pkg/analyzer/lib/src/generated/engine.dart
+++ b/pkg/analyzer/lib/src/generated/engine.dart
@@ -2371,7 +2371,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
}
ChangeNoticeImpl notice = _getNotice(source);
notice.compilationUnit = unit;
- notice.resolved = true;
notice.setErrors(dartEntry.allErrors, lineInfo);
}
}
@@ -2456,7 +2455,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
}
ChangeNoticeImpl notice = _getNotice(source);
notice.compilationUnit = unit;
- notice.resolved = true;
notice.setErrors(dartEntry.allErrors, lineInfo);
}
}
@@ -4629,7 +4627,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
if (unit != null) {
ChangeNoticeImpl notice = _getNotice(task.source);
notice.compilationUnit = unit;
- notice.resolved = true;
_incrementalAnalysisCache =
IncrementalAnalysisCache.cacheResult(task.cache, unit);
}
@@ -4691,8 +4688,7 @@ class AnalysisContextImpl implements InternalAnalysisContext {
_cache.storedAst(source);
ChangeNoticeImpl notice = _getNotice(source);
if (notice.compilationUnit == null) {
- notice.compilationUnit = task.compilationUnit;
- notice.resolved = false;
+ notice.parsedDartUnit = task.compilationUnit;
}
notice.setErrors(dartEntry.allErrors, task.lineInfo);
// Verify that the incrementally parsed and resolved unit in the incremental
@@ -4772,7 +4768,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
_cache.storedAst(source);
ChangeNoticeImpl notice = _getNotice(source);
notice.htmlUnit = task.resolvedUnit;
- notice.resolved = true;
LineInfo lineInfo = htmlEntry.getValue(SourceEntry.LINE_INFO);
notice.setErrors(htmlEntry.allErrors, lineInfo);
return htmlEntry;
@@ -5070,7 +5065,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
LineInfo lineInfo = getLineInfo(source);
ChangeNoticeImpl notice = _getNotice(source);
notice.compilationUnit = unit;
- notice.resolved = true;
notice.setErrors(dartEntry.allErrors, lineInfo);
});
// OK
@@ -7246,24 +7240,22 @@ class CacheState extends Enum<CacheState> {
*/
abstract class ChangeNotice implements AnalysisErrorInfo {
/**
* Return the AST that changed as a result of the analysis, or `null` if the
* AST was not changed. Use the getter [resolved] to determine whether the
* AST has been fully resolved.
*/
- CompilationUnit get compilationUnit;
+ CompilationUnit get parsedDartUnit;
/**
* Return the HTML that changed as a result of the analysis, or `null` if the
* HTML was not changed. Use the getter [resolved] to determine whether the
* HTML has been fully resolved.
*/
- ht.HtmlUnit get htmlUnit;
+ CompilationUnit get compilationUnit;
Brian Wilkerson 2015/01/26 19:11:03 Should we change the name to "resolvedDartUnit" fo
/**
- * Return `true` if the [compilationUnit] or [htmlUnit] (whichever is
- * currently set) has been resolved.
+ * The fully resolved HTML AST that changed as a result of the analysis, or
+ * `null` if the AST was not changed.
*/
- bool get resolved;
+ ht.HtmlUnit get htmlUnit;
Brian Wilkerson 2015/01/26 19:11:03 "resolvedHtmlUnit"?
/**
* Return the source for which the result is being reported.
@@ -7286,24 +7278,22 @@ class ChangeNoticeImpl implements ChangeNotice {
final Source source;
/**
* The AST that changed as a result of the analysis, or `null` if the AST was
* not changed. Use the getter [resolved] to determine whether the AST has
* been fully resolved.
*/
- CompilationUnit compilationUnit;
+ CompilationUnit parsedDartUnit;
/**
* The HTML that changed as a result of the analysis, or `null` if the HTML
* was not changed. Use the getter [resolved] to determine whether the HTML
* has been fully resolved.
*/
- ht.HtmlUnit htmlUnit;
+ CompilationUnit compilationUnit;
/**
- * A flag indicating whether the [compilationUnit] or [htmlUnit] (whichever is
- * currently set) has been resolved.
+ * The fully resolved HTML AST that changed as a result of the analysis, or
+ * `null` if the AST was not changed.
*/
- bool resolved = false;
+ ht.HtmlUnit htmlUnit;
/**
* The errors that changed as a result of the analysis, or `null` if errors
« no previous file with comments | « pkg/analysis_server/lib/src/operation/operation_analysis.dart ('k') | no next file » | no next file with comments »
@@ -7246,24 +7240,22 @@ class CacheState extends Enum<CacheState> {
abstract class ChangeNotice implements AnalysisErrorInfo {
/**
- * Return the AST that changed as a result of the analysis, or `null` if the
- * AST was not changed. Use the getter [resolved] to determine whether the
- * AST has been fully resolved.
+ * The parsed, but maybe not resolved Dart AST that changed as a result of
+ * the analysis, or `null` if the AST was not changed.
*/
@@ -7246,24 +7240,22 @@ class CacheState extends Enum<CacheState> {
/**
- * Return the HTML that changed as a result of the analysis, or `null` if the
- * HTML was not changed. Use the getter [resolved] to determine whether the
- * HTML has been fully resolved.
+ * The fully resolved Dart AST that changed as a result of the analysis, or
+ * `null` if the AST was not changed.
*/
@@ -7286,24 +7278,22 @@ class ChangeNoticeImpl implements ChangeNotice {
final Source source;
/**
- * The AST that changed as a result of the analysis, or `null` if the AST was
- * not changed. Use the getter [resolved] to determine whether the AST has
- * been fully resolved.
+ * The parsed, but maybe not resolved Dart AST that changed as a result of
+ * the analysis, or `null` if the AST was not changed.
*/
@@ -7286,24 +7278,22 @@ class ChangeNoticeImpl implements ChangeNotice {
/**
- * The HTML that changed as a result of the analysis, or `null` if the HTML
- * was not changed. Use the getter [resolved] to determine whether the HTML
- * has been fully resolved.
+ * The fully resolved Dart AST that changed as a result of the analysis, or
+ * `null` if the AST was not changed.
*/

Powered by Google App Engine
This is Rietveld 408576698